-- -----------------------------------------------
--   Correccion de SP para busqueda de productos
-- -----------------------------------------------
DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_producto_x_codigo`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_producto_x_codigo`(
	p_codigo VARCHAR(30)
)
    COMMENT 'Busqueda de Producto por Codigo'
BEGIN
	SELECT 1 AS cantidad,
		prd.modelo,
		prd.nombre AS descripcion,
		prd.precio_venta AS precio_unitario,
		prd.precio_venta,
		0.00 AS subtotal,
		0.00 AS iva,
		0.00 AS total,
		prd.tasa_iva,
		prd.iva_incluido,
		prd.imagen,
		prd.id_producto,
		prd.clave
	FROM cat_productos_servicios AS prd
	JOIN cat_configuracion AS cfg
	WHERE BINARY prd.clave = p_codigo
		OR BINARY LEFT(prd.clave, cfg.group_len) = p_codigo
		OR BINARY prd.modelo = p_codigo;
END$$

DELIMITER ;


-- -------------------------------------------------------------------
--   Eliminar procedimiento anterior de verificaion de corte de caja
-- -------------------------------------------------------------------
DROP PROCEDURE IF EXISTS `stp_existeCorteCajaHoy`;


-- ------------------------------------------------------
--   Correccion de SP para vrificacion de corte de caja
-- ------------------------------------------------------
DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_requiereCorteCaja`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_requiereCorteCaja`(
	p_id_user INT
)
    SQL SECURITY INVOKER
    COMMENT 'Verifica si usuario que incia sesion requiere generar corte'
BEGIN
	DECLARE idUsuarioUltimoCorte INT;
	DECLARE hoy DATE;
	SET idUsuarioUltimoCorte = 0;
	SET hoy = CAST(NOW() AS DATE);
	
	SELECT cc.id_usuario_caja INTO idUsuarioUltimoCorte
	FROM tbl_cortes_caja AS cc
	WHERE CAST(cc.fecha_corte AS DATE) = hoy
	ORDER BY cc.fecha_corte DESC
	LIMIT 1;
	
	-- Retorna el resultado
	SELECT IF(p_id_user <> COALESCE(idUsuarioUltimoCorte, 0), 0, 1) AS existe_corte;
END$$

DELIMITER ;
